@@ -23,7 +23,7 @@ from .utils import read_yaml
 
 from .database import open_database
 
-__version__ = "0.7.3"
+__version__ = "0.7.4"
 
 log = logging.getLogger(__name__)
 
@@ -236,7 +236,7 @@ def setup_ns(ns):
     ns.C.range_outside = 'red'
     ns.C.all_seen = 'magenta'
     ns.C.warning = 'red'
-    ns.C.warning = 'bold_magenta'
+    ns.C.title = 'bold_magenta'
 
 
 def main(args):
